#ifndef _EUROPA_H_
#define _EUROPA_H_

// This is a list of possible error codes returned from the update utility's
// file routines

typedef enum
{
	EUROPA_NO_ERROR,
	EUROPA_CANT_OPEN_FILE,
	EUROPA_CRC_ERROR,
	EUROPA_IMAGE_CORRUPT,
	EUROPA_UNKNOWN_VERSION,
	EUROPA_CANCELED,
	EUROPA_RESPONSE_TOO_LONG,
	EUROPA_RESPONSE_TIMEOUT,
	EUROPA_BAD_RESPONSE,
	EUROPA_ERASE_FAILURE,
	EUROPA_NO_MEMORY,
	EUROPA_BAD_CHECKSUM,
	EUROPA_BAD_LENGTH,
	EUROPA_BAD_SEQUENCE,
	EUROPA_BAD_CHECKCODE,
	EUROPA_PROGRAM_FAULT
} EEuropaError;

// Packing file commands

typedef enum
{
	ECMD_EUROPA_IMAGE,		// 00
	ECMD_INVALID,				// Ignore me! Here for legacy reasons
	ECMD_DELAY,					// 01
	ECMD_RESET,					// 02
	ECMD_END_OF_LIST,
	ECMD_EOF=0xff
} EEuropaFileCommand;

// Reset reasons

typedef enum
{
	RESET_NORMAL,
	RESET_ROLAND,
	RESET_FIRMWARE_TRANSFER_MODE,
	RESET_EUROPA_RESTART,
	RESET_MAX
} EResetReason;

// Europa version

#define EUROPA_VERSION_SUPPORTED		0x00

// Image status field

typedef enum
{
	IMAGE_INSTALLED_OK,
	IMAGE_INSTALLED_BAD,
	IMAGE_NOT_PRESENT
} EImageStatus;

// Processor type

typedef enum
{
	PROC_PHILIPS_P89C51RD2,
	PROC_TEMIC_T89C51RD2
} EProcessorType;

// Europa Sysex commands

typedef enum
{
	ESYSEX_RESET=0x10,
	ESYSEX_GET_REVS,
	ESYSEX_REV_RESPONSE,
	ESYSEX_PREPARE_AREA,
	ESYSEX_PREPARE_RESPONSE,
	ESYSEX_PROGRAM_BLOCK,
	ESYSEX_PROGRAM_RESPONSE
} EEuropaSysexCommands;

// Prepare area responses

typedef enum
{
	PREPARE_OK,
	PREPARE_ERASE_FAILURE,
	PREPARE_BAD_AREA
} EEuropaPrepareResponses;

// Program block responses

typedef enum
{
	PROGRAM_OK,
	PROGRAM_BAD_CHECKSUM,
	PROGRAM_BAD_LENGTH,
	PROGRAM_BAD_BLOCK_SEQUENCE,
	PROGRAM_UNEXPECTED,
	PROGRAM_FAULT,
	PROGRAM_COMPLETE_BAD_CHECKCODE,
	PROGRAM_COMPLETE_IMAGE_OK,
	PROGRAM_DATA_TOO_LONG
} EEuropaProgramResponses;

// Length of our serial #

#define	EUROPA_SERIAL_NUMBER_LENGTH	6

// This is Europa's installed status structure

struct sEuropaStatus
{
	EImageStatus eEuropaStatus;
	UINT8 u8EuropaMajorVersion;
	UINT8 u8EuropaMinorVersion;
	UINT8 u8NotUsed[3];				// 3 Bytes not used
	UINT16 u16MaxBlockTransferSize;
	UINT8 u8BootBlockMonth;
	UINT8 u8BootBlockDay;
	UINT16 u16BootBlockYear;
	EProcessorType eProcType;
	UINT8 u8SerialNumber[(EUROPA_SERIAL_NUMBER_LENGTH*2)+1];
	UINT8 u8EuropaVersionText[15];
};

#endif
